@@ -1,4 +1,4 @@
-/* $Id: dict.c,v 1.22 2003/05/19 19:46:00 merchan Exp $ */
+/* $Id: dict.c,v 1.25 2005/02/11 16:52:44 vnoel Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -28,8 +28,8 @@
 
 #include <unistd.h>
 
-#include <glib.h>
-#include <gnome.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 
 #include "dict.h"
 
@@ -266,7 +266,7 @@ static void data_notify_match (dict_context_t *context, char *line)
             break;
             
 	default:
-            g_error ("Invalid status code given");
+            g_error ("Invalid status code given 1");
         }
         break;
         
@@ -373,7 +373,7 @@ static void data_notify_define (dict_context_t *context, char *line)
             break;
             
 	default:
-            g_error ("Invalid status code given");
+            g_error ("Invalid status code given 2");
         }
         break;
         
@@ -443,9 +443,15 @@ static void data_notify_show_db (dict_context_t *context, char *line)
 		command->status_notify_cb (command, status_code, 0,
 					   command->user_data);
             break;
-            
+	case DICT_STATUS_CONNECT:
+	case DICT_STATUS_BAD_COMMAND:
+		dict_command_done (command);
+		if (command->error_notify_cb)
+			command->error_notify_cb (command, status_code, line,
+						  command->user_data);
+		break;
 	default:
-            g_error ("Invalid status code given");
+            g_error ("Invalid status code given 3");
         }
         break;
         
@@ -508,7 +514,7 @@ static void data_notify_show_strat (dict_context_t *context,
         while (isspace (*line)) line++;
         
         num_found = 0;
-        
+
         switch (status_code) {
 	case DICT_STATUS_STRAT_PRESENT:
             num_found = atoi (line);
@@ -525,9 +531,15 @@ static void data_notify_show_strat (dict_context_t *context,
 		command->status_notify_cb (command, status_code, 0,
 					   command->user_data);
             break;
-            
+	case DICT_STATUS_CONNECT:
+	case DICT_STATUS_BAD_COMMAND:
+		dict_command_done (command);
+		if (command->error_notify_cb)
+			command->error_notify_cb (command, status_code, line,
+						  command->user_data);
+		break;
 	default:
-            g_error ("Invalid status code given");
+            g_error ("Invalid status code given 4");
         }
         break;
         
@@ -671,10 +683,11 @@ static gboolean dict_data_notify (GIOChannel *channel, GIOCondition cond,
         /* Strange error here */
         
         dict_disconnect (context);
-        dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
-                                         GTK_MESSAGE_ERROR,
-                                         GTK_BUTTONS_OK,
-                                         _("A serious error occured. Please check that your server and port are correct. For reference the default server is dict.org and the port 2628"));
+        dialog = gtk_message_dialog_new_with_markup (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+						     GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+						     "<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s",
+						     _("Server Error"),
+						     _("A serious error occured. Please check that your server and port are correct. For reference the default server is dict.org and the port 2628"));
         g_signal_connect_swapped (GTK_OBJECT (dialog), "response",
                                   G_CALLBACK (gtk_widget_destroy),
                                   GTK_OBJECT (dialog));
