@@ -1,4 +1,4 @@
-/* $Id: gdict-speller.c,v 1.41 2005/01/18 20:56:55 vnoel Exp $ */
+/* $Id: gdict-speller.c,v 1.41.2.1 2005/03/27 15:53:44 vuntz Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -111,7 +111,7 @@ gdict_speller_init (GDictSpeller *speller)
 	gtk_box_set_spacing (GTK_BOX (vbox), 3);
 	
 	hbox = gtk_hbox_new (FALSE, 0);
-	label = gtk_label_new ("Spellings");
+	label = gtk_label_new (_("Spellings"));
 	gtk_misc_set_alignment (GTK_MISC(label), 0., 0.5);
 	gtk_box_pack_start (GTK_BOX(hbox), label, TRUE, TRUE, 0);
 	button = gdict_button_new_with_stock_image (NULL, GTK_STOCK_CLOSE);
