@@ -20,20 +20,10 @@
 
 #include "config.h"
 
-#include <glib.h>
-#include <gnome.h>
-
-#include <stdio.h>
+#include <glib/gi18n.h>
 #include <fcntl.h>
-#include <errno.h>
-#include <unistd.h>
-#include <stdlib.h>
 #include <sys/stat.h>
-#include <sys/ioctl.h>
 #include <sys/wait.h>
-#include <linux/major.h>
-#include <linux/kdev_t.h>
-#include <string.h>
 
 #ifdef HAVE_LINUX_FD_H
 #include <linux/fd.h>
