@@ -22,14 +22,14 @@
 #  include <config.h>
 #endif
 
-#include <fcntl.h>
-#include <gnome.h>
-#include <gconf/gconf-client.h>
-#include <libgnomeui/gnome-window-icon.h>
-#include <glade/glade.h>
 #include <unistd.h>
-#include <sys/types.h>
-#include <errno.h>
+#include <fcntl.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
+#include <gconf/gconf-client.h>
+#include <libgnome/gnome-help.h>
+#include <libgnomeui/gnome-ui-init.h>
+#include <glade/glade.h>
 
 #ifdef USE_HAL
 #  include <hal/libhal.h>
@@ -41,8 +41,6 @@
 
 #define NUM_DEVICES_TO_CHECK 4
 
-extern int errno;
-
 static GFloppy floppy;
 static GladeXML *xml;
 static GtkWidget *toplevel = NULL;
@@ -69,6 +67,24 @@ static void set_widget_sensitive_from  (GtkToggleButton *button,
 					gpointer         data);
 */
 
+static void
+show_error_dialog (GtkWidget *parent, gchar *main, gchar *secondary)
+{
+	GtkWidget *dialog;
+	GtkDialogFlags flags;
+	
+	if (parent != NULL)
+		flags = GTK_DIALOG_MODAL;
+	
+	dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW(parent), flags, 
+						     GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+						     "<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s",
+						     main, secondary);
+	gtk_window_set_title (GTK_WINDOW (dialog), "");
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
+}
+
 static void 
 floppy_status_free (FloppyStatus *floppies, gint num_floppies)
 {
@@ -182,8 +198,6 @@ get_hal_floppies (gint *num_devices, gint *num_ok, LibHalContext *ctx)
 
 #endif
 
-#include <stdlib.h>
-
 static void
 init_commands (void)
 {
@@ -207,16 +221,8 @@ init_commands (void)
 	if (!floppy.mke2fs_cmd &&
 	    !floppy.mkdosfs_cmd &&
 	    !floppy.mformat_cmd) {
-		GtkWidget *error_dialog;
-
-		error_dialog = gtk_message_dialog_new (NULL, 0,
-						       GTK_MESSAGE_ERROR,
-						       GTK_BUTTONS_OK,
-						       _("Neither the mke2fs nor the mkdosfs/mformat applications are installed. You can't format a floppy without one of them."));
-
-		gtk_dialog_run (GTK_DIALOG (error_dialog));
-		gtk_widget_destroy (error_dialog);
-
+		show_error_dialog (NULL, _("Cannot Format"),
+				   _("Neither the mke2fs nor the mkdosfs/mformat applications are installed. You can't format a floppy without one of them."));
 		exit (1);
 	}
 }
@@ -249,15 +255,7 @@ init_devices (gpointer ctx)
 		}
 		if (msg) {
 			GtkWidget *toplevel = glade_xml_get_widget (xml, "toplevel");
-			GtkWidget *dialog;
-
-			gtk_widget_set_sensitive (toplevel, FALSE);
-			dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel), 0,
-							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_OK,
-							 msg);
-			gtk_dialog_run (GTK_DIALOG (dialog));
-			gtk_widget_destroy (dialog);
+			show_error_dialog (toplevel, _("Cannot initialize device"), msg);
 			exit (1);
 		}
 		/* Device is okay */
@@ -321,13 +319,7 @@ init_devices (gpointer ctx)
 
 			toplevel = glade_xml_get_widget (xml, "toplevel");
 			gtk_widget_set_sensitive (toplevel, FALSE);
-			dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel), 0,
-							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_OK,
-							 msg);
-			g_free (msg);
-			gtk_dialog_run (GTK_DIALOG (dialog));
-			gtk_widget_destroy (dialog);
+			show_error_dialog (toplevel, _("Cannot initialize device"), msg);
 			exit (1);
 		} else if (ok_devices_present == 1) {
 			for (i = 0; i < num_devices_to_check; i++)
@@ -477,25 +469,10 @@ on_help_button_clicked (GtkWidget *widget, gpointer user_data)
 {
 	GError *error = NULL;
 
-	gnome_help_display_desktop (NULL, "user-guide",
-				    "user-guide.xml",
-				    "gosnautilus-469", &error);
-
+	gnome_help_display_desktop_on_screen (NULL, "gfloppy", "gfloppy", "usage", 
+					      gtk_widget_get_screen (widget), &error);
 	if (error) {
-		GtkWidget *dialog;
-
-		dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel), GTK_DIALOG_MODAL,
-						 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-						 _("Could not display help for the "
-						   "floppy formatter.\n"
-						   "%s"),
-						 error->message);
-
-		g_signal_connect (dialog, "response",
-				  G_CALLBACK (gtk_widget_destroy), NULL);
-		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-		gtk_widget_show (dialog);
-
+		show_error_dialog (toplevel, _("Could not display help for the floppy formatter."), error->message);
 		g_error_free (error);
 	}
 }
@@ -514,15 +491,8 @@ on_format_button_clicked (GtkWidget *widget, gpointer user_data)
 	floppy.volume_name = (char *) gtk_entry_get_text (GTK_ENTRY (volume_name_entry));
 
 	if (strstr (floppy.volume_name, " ")) {
-		GtkWidget *dialog;
-
-		dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel), GTK_DIALOG_MODAL,
-						 GTK_MESSAGE_ERROR,
-						 GTK_BUTTONS_OK,
-						 _("The volume name can't contain any blank space."));
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
-
+		show_error_dialog (toplevel, _("Incorrect volume name"),
+				   _("The volume name can't contain any blank space."));
 		return;
 	}
 
@@ -548,11 +518,8 @@ on_format_button_clicked (GtkWidget *widget, gpointer user_data)
 int
 main (int argc, char *argv[])
 {
-	const GnomeIconData *icon_data;
-	char *icon_path = NULL;
 	GConfClient *client;
 	GFloppyConfig config;
-        GnomeIconTheme *icon_theme;
 	GtkWidget *fs_entry;
 	GtkWidget *type_option;
 	GtkWidget *quick_format_rb;
@@ -560,6 +527,7 @@ main (int argc, char *argv[])
 	GtkWidget *label;
 	GtkSizeGroup *size_group;
 	GSList *l;
+	gchar *label_text;
         gint base_size;
 
 
@@ -589,13 +557,7 @@ main (int argc, char *argv[])
 	ctx = (gpointer) hal_initialize (NULL, FALSE);
 #endif
 
-        icon_theme = gnome_icon_theme_new ();
-        icon_path = gnome_icon_theme_lookup_icon (icon_theme, "gnome-dev-floppy", 24.0,
-                                                              &icon_data, &base_size);
-
-        if (icon_path)
-	  gnome_window_icon_set_default_from_file (icon_path);
-	g_free (icon_path);
+	gtk_window_set_default_icon_name ("gnome-dev-floppy");
 
 	init_commands ();
 
@@ -606,8 +568,6 @@ main (int argc, char *argv[])
 	if (xml == NULL)
 		g_error ("Cannot load/find gfloppy2.glade");
 
-	init_devices (ctx);
-
 	/* We get the different widgets */
 	
 	toplevel = glade_xml_get_widget (xml, "toplevel");
@@ -667,6 +627,22 @@ main (int argc, char *argv[])
 	default_mode_rb = (GtkWidget *) g_slist_nth (l, GFLOPPY_FORMAT_THOROUGH - config.default_formatting_mode)->data;
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (default_mode_rb), TRUE);
 
+	/* bold header labels per HIG; done here to avoid markup in translations */
+	label = glade_xml_get_widget (xml, "physical_label");
+	label_text = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>", gtk_label_get_text (GTK_LABEL (label)));
+	gtk_label_set_markup (GTK_LABEL (label), label_text);
+	g_free (label_text);
+
+	label = glade_xml_get_widget (xml, "filesystem_label");
+	label_text = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>", gtk_label_get_text (GTK_LABEL (label)));
+	gtk_label_set_markup (GTK_LABEL (label), label_text);
+	g_free (label_text);
+
+	label = glade_xml_get_widget (xml, "formatting_label");
+	label_text = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>", gtk_label_get_text (GTK_LABEL (label)));
+	gtk_label_set_markup (GTK_LABEL (label), label_text);
+	g_free (label_text);
+
 	/* check the UI consistency for a couple of settings */
 	g_signal_emit_by_name (type_option, "changed", NULL);
 
@@ -694,6 +670,8 @@ main (int argc, char *argv[])
 		gtk_label_set_mnemonic_widget (GTK_LABEL(label), GTK_WIDGET(fs_entry));
 	}
 
+	init_devices (ctx);
+
 	gtk_widget_show (GTK_WIDGET (toplevel));
 
 	gtk_main ();
