@@ -32,7 +32,6 @@
 #include <glib/gi18n.h>
 #include <regex.h>
 #include <gdk/gdkx.h>
-#include <bonobo-activation/bonobo-activation.h>
 #include <libgnomevfs/gnome-vfs-mime.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <libgnomevfs/gnome-vfs-ops.h> 
@@ -763,25 +762,6 @@ get_file_pixbuf_for_mime_type (GHashTable * hash,
 	return pixbuf;
 }
 
-gboolean
-is_nautilus_running (void)
-{
-	CORBA_Environment ev;
-	CORBA_Object obj;
-	gboolean ret;
-	
-	CORBA_exception_init (&ev); 
-	obj = bonobo_activation_activate_from_id ("OAFIID:Nautilus_Factory",
-		Bonobo_ACTIVATION_FLAG_EXISTING_ONLY, NULL, &ev);
-		
-	ret = !CORBA_Object_is_nil (obj, &ev);
-	
-	CORBA_Object_release (obj, &ev);	
-	CORBA_exception_free (&ev);
-	
-	return ret;
-}
-
 gboolean
 open_file_with_nautilus (GtkWidget * window,
                          const gchar * file)
@@ -884,7 +864,7 @@ open_file_with_application (GtkWidget * window,
 				 	screen = gtk_widget_get_screen (window);
 					gnome_desktop_item_set_launch_time (ditem, gtk_get_current_event_time ());
 					gnome_desktop_item_launch_on_screen (ditem, uris, 
-						GNOME_DESKTOP_ITEM_LAUNCH_APPEND_URIS, screen, -1, &error);
+						GNOME_DESKTOP_ITEM_LAUNCH_APPEND_PATHS, screen, -1, &error);
 					if (error) {
 						result = FALSE;			
 						g_error_free (error);
