@@ -18,37 +18,19 @@
 
     ---------------------------------------------------------------------- */
 
-
-#include <config.h>
-#include <time.h>
-#include <gnome.h>
+#include <glib/gi18n.h>
 #include "gtk/gtk.h"
 #include "logview.h"
 #include "calendar.h"
 
-#define CALENDAR_WIDTH           180
-#define CALENDAR_HEIGHT          150
-
-#define SUNDAY                   0
-#define MONDAY                   1
-#define FRIDAY                   5
-#define SATURDAY                 6
-#define FEBRUARY                 1
-#define XSEP                     3
-#define CALLEFTMARGIN            5
-#define BASELINESKIP             4
-
-#define THISMONTH                1
-#define OTHERMONTH               2
-#define MARKEDDATE               3
-
-/*
- *       ----------------
- *       Global variables
- *       ----------------
- */
-
-extern char *month[12];
+static void calendar_day_selected (GtkWidget *widget, LogviewWindow *window);
+static void calendar_day_selected_double_click (GtkWidget *widget, LogviewWindow *window);
+static void close_calendar (GtkWidget * widget, int arg, gpointer client_data);
+static DateMark* find_prev_mark (CalendarData*);
+static DateMark* find_next_mark (CalendarData*);
+static DateMark* get_mark_from_month (CalendarData *data, gint month, gint year);
+static DateMark *get_mark_from_date (CalendarData *, gint, gint, gint);
+static void calendar_month_changed (GtkWidget *widget, LogviewWindow *window);
 
 /* ----------------------------------------------------------------------
    NAME:          CalendarMenu
@@ -95,15 +77,15 @@ CalendarMenu (LogviewWindow *window)
 
       calendar = (GtkCalendar *)gtk_calendar_new();
 
-      gtk_signal_connect (GTK_OBJECT (calendar), "month_changed",
-			  GTK_SIGNAL_FUNC (calendar_month_changed),
-			  window);
-      gtk_signal_connect (GTK_OBJECT (calendar), "day_selected",
-			  GTK_SIGNAL_FUNC (calendar_day_selected),
-			  window);
-      gtk_signal_connect (GTK_OBJECT (calendar), "day_selected_double_click",
-			  GTK_SIGNAL_FUNC (calendar_day_selected_double_click),
-			  window);
+      g_signal_connect (G_OBJECT (calendar), "month_changed",
+			G_CALLBACK (calendar_month_changed),
+			window);
+      g_signal_connect (G_OBJECT (calendar), "day_selected",
+			G_CALLBACK (calendar_day_selected),
+			window);
+      g_signal_connect (G_OBJECT (calendar), "day_selected_double_click",
+			G_CALLBACK (calendar_day_selected_double_click),
+			window);
       gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (calendar), TRUE, TRUE, 0);
       gtk_widget_show (GTK_WIDGET (calendar));
 
@@ -115,9 +97,11 @@ CalendarMenu (LogviewWindow *window)
 
       window->calendar_dialog = CalendarDialog;
       window->calendar = CalendarWidget;
-      init_calendar_data (window);
    }
 
+   if (window->curlog->caldata == NULL)
+	   init_calendar_data (window);
+
    window->calendar_visible = TRUE;
    gtk_widget_show (window->calendar_dialog);
 
@@ -179,15 +163,10 @@ init_calendar_data (LogviewWindow *window)
        data->curmonthmark = window->curlog->lstats.firstmark;
        window->curlog->caldata = data;
 
-#if 0
-       /* Move mark to first marked date in this month */
-       data->curmonthmark = 
-	 get_mark_from_month (data, window->curlog->curmark->fulldate.tm_mon,
-			      window->curlog->curmark->fulldate.tm_year);
-#endif
+       read_marked_dates (data, window);
        
        /* signal a redraw event */
-       gtk_signal_emit_by_name (GTK_OBJECT (window->calendar), "month_changed");
+       g_signal_emit_by_name (GTK_OBJECT (window->calendar), "month_changed");
        
      }
 
@@ -199,7 +178,7 @@ init_calendar_data (LogviewWindow *window)
    DESCRIPTION:   User changed the month in the calendar.
    ---------------------------------------------------------------------- */
 
-void
+static void
 calendar_month_changed (GtkWidget *widget, LogviewWindow *window)
 {
   GtkCalendar *calendar;
@@ -269,10 +248,8 @@ close_calendar (GtkWidget *widget, int arg, gpointer data)
 {
    LogviewWindow *window = LOGVIEW_WINDOW (data);
    if (window->calendar_visible) {
-      gtk_widget_hide (window->calendar_dialog);
-      gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM
-				      (gtk_ui_manager_get_widget(window->ui_manager, "/LogviewMenu/ViewMenu/ShowCalendar")),
-				      FALSE);
+	   GtkAction *action = gtk_ui_manager_get_action (window->ui_manager, "/LogviewMenu/ViewMenu/ShowCalendar");
+	   gtk_action_activate (action);
    }
    window->calendar_visible = FALSE;
 }
