@@ -108,7 +108,7 @@ static GtkActionEntry entries[] = {
 
        	{ "HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1", N_("Open the help contents for the log viewer"), 
 	  G_CALLBACK (logview_help) },
-	{ "AboutAction", GTK_STOCK_ABOUT, N_("_About"), NULL, N_("Show the about dialog for the gconf editor"), 
+	{ "AboutAction", GTK_STOCK_ABOUT, N_("_About"), NULL, N_("Show the about dialog for the log viewer"), 
 	  G_CALLBACK (AboutShowWindow) },
 
 };
@@ -891,6 +891,8 @@ logview_set_window_title (LogviewWindow *window)
 			logname = window->curlog->name;
 		
 		if (window->monitored) 
+		  /* For translators : this is the window title that shows the log and
+		     app names : "logname (monitored) - APP_NAME" */
 			window_title = g_strdup_printf (_("%s (monitored) - %s"), logname, APP_NAME);
 		else
 			window_title = g_strdup_printf ("%s - %s", logname, APP_NAME);
